import * as React from 'react';
export { useInView } from './hooks/useInView';
export { useIntersectionObserver } from './hooks/useIntersectionObserver';
export declare type RenderProps = {
    inView: boolean;
    intersection: IntersectionObserverEntry | undefined;
    ref: React.RefObject<any> | ((node?: Element | null) => void);
};
export declare type IntersectionOptions = {
    /** Number between 0 and 1 indicating the the percentage that should be visible before triggering. Can also be an array of numbers, to create multiple trigger points. */
    threshold?: number | Array<number>;
    /** The HTMLElement that is used as the viewport for checking visibility of the target. Defaults to the browser viewport if not specified or if null.*/
    root?: Element;
    /** Margin around the root. Can have values similar to the CSS margin property, e.g. "10px 20px 30px 40px" (top, right, bottom, left). */
    rootMargin?: string;
    /** Only trigger the inView callback once */
    triggerOnce?: boolean;
};
export declare type IntersectionObserverProps = IntersectionOptions & {
    /**
     * Children expects a function that receives an object
     * contain an `inView` boolean and `ref` that should be
     * assigned to the element root.
     */
    children?: React.ReactNode | ((fields: RenderProps) => React.ReactNode);
    /**
     * Render the wrapping element as this element.
     * @default `'div'`
     */
    as?: string;
    /**
     * Element tag to use for the wrapping component
     * @deprecated Replace with the 'as' prop
     */
    tag?: string;
    /** Call this function whenever the in view state changes */
    onChange?: (inView: boolean, intersection: IntersectionObserverEntry) => void;
};
declare type State = {
    inView: boolean;
    intersection?: IntersectionObserverEntry;
};
/**
 * Monitors scroll, and triggers the children function with updated props
 *
 <InView>
 {({inView, ref}) => (
   <h1 ref={ref}>{`${inView}`}</h1>
 )}
 </InView>
 */
export declare class InView extends React.Component<IntersectionObserverProps, State> {
    static defaultProps: {
        threshold: number;
        triggerOnce: boolean;
    };
    state: {
        inView: boolean;
        intersection: undefined;
    };
    componentDidMount(): void;
    componentDidUpdate(prevProps: IntersectionObserverProps, prevState: State): void;
    componentWillUnmount(): void;
    node: HTMLElement | null;
    observeNode(): void;
    handleNode: (node?: HTMLElement | undefined) => void;
    handleChange: (inView: boolean, intersection: IntersectionObserverEntry) => void;
    render(): any;
}
export default InView;
